package jam.operator;

import  jam.vector.Vector;

/**
 * <TT>BiLinearOperatorAdjoint</TT> is a <TT>BiLinearOperator</TT>
 * in which the two underlying linear operators have adjoints implemented.
 * <BR>
 * <BR><!--#include file="./source.inc"--><BR>
 * <BR>
 * Should we include the PartialAdjoint as is done in HCL:<BR>
 * // access to the "partial adjoint" of the bilinear operator:<BR>
 * // Assume A:XxY --> Z is the bilinear operator.<BR>
 * // Then this method returns the operator x |---> (A(x))'z.<BR>
 * // Its adjoint is the operator y |---> (A(.)y)'z<BR>
 * public hasAdjoint getPartialAdjoint(Vector z);<BR>
 *
 * @author    Joel Schroeder
 */
public interface BiLinearOperatorAdjoint
extends jam.JamObject, BiLinearOperator {
  /**
   * A BiLinearOperator in components is A_{ijk}     <BR>
   * Here, the first index, i, indicates the range.  <BR>
   * By contracting A with a vector in the range, r_{i}, we get a linear
   * operator: <BR>
   * B_{jk} = A_{ijk} * r_{i}     (sum over i)       <BR>
   * This is what I mean by the "partial adjoint".
   * It is an operator with adjoint which maps the spaces: <BR>
   * B :      domain2 ---> domain1                   <BR>
   * adj(B) : domain1 ---> domain2                   <BR>
   * <BR>
   * Why does the adjoint of B map from domain1 instead of B itself?
   * We use the convention that the first index from the left indicates
   * the range index.  In A_{ijk}, j is for domain1 and k is for domain2.
   * Thus, B_{jk} maps from domain2 to domain1.
   */
  public hasAdjoint getPartialAdjoint(Vector r);
}
