package jam.operator;

/**
 * <TT>BiLinearOperatorHessian</TT> is a <TT>BiLinearOperatorAdjoint</TT>
 * in which the derivatives, gradients, and hessian have been implemented.
 * <BR>
 *
 * The derivative of a bilinear operator B(x,y) at a point [x0 y0]'
 * (where we consider B(x,y) as a non-linear (unary) operator of [x y]')
 * is the row operator:<BR>
 * [B(.,y0) B(x0,.)]   <BR>
 * That is:            <BR>
 * Derivative at [x0 y0]' acting on [x y]' = B(x,y0) + B(x0,y)
 * <BR><BR>
 * The Hessian of a bilinear operator considered as a unary operator is
 * very simple: <BR>
 * Hessian([x y]', [v w]') = B(x,w) + B(v,y)  <BR>
 * The Hessian is independent of its place of evaluation ([x0 y0]').
 * In fact, not surprisingly, the full Taylor expansion of B ends with
 * the Hessian, i.e. there are no terms higher than second order. <BR>
 * The bilinear property of B gives us the Taylor expansion immediately:<BR>
 * B(x+x0, y+y0) = B(x0,y0) + {B(x,x0) + B(x0,y)} + (1/2){2B(x,y)}      <BR>
 *
 * <BR><!--#include file="./source.inc"--><BR>
 *
 * @author    Joel Schroeder
 */
public interface BiLinearOperatorHessian
extends jam.JamObject, BiLinearOperatorAdjoint, hasHessian {}
