package jam.operator;

import  jam.JamObject;
import  jam.vector.*;

/**
 * An <TT>Operator</TT> is a function mapping one vector space to another.
 * <BR>
 * This includes the case in which the range is the real numbers.<BR>
 * (Such a map from vectors to reals is traditionally called a functional).
 * <BR><BR>
 * <BR><!--#include file="./source.inc"--><BR>
 * An <TT>Operator</TT> could be a <TT>Vector</TT> (without the inner
 * product), but currently is not because of certain implementation
 * details.<BR> We cannot see much of a benefit to uniting the Vector
 * and Operator classes.
 * 
 * @author      Joel Schroeder
 */
public interface Operator extends JamObject {
  public Space getDomain();
  public Space getRange ();

  /**
   * @return new this(d)
   */
  public Vector       image   (Vector d);
  /**
   * @param r = this(d)
   */
  public void         image   (Vector d,
                               Vector r);
  /**
   * @param r = this(d) + r
   */
  public void         addImage(Vector d,
                               Vector r);
  /**
   * @param r = this(d) - b
   */
  public void         residual(Vector d,
                               Vector b,
                               Vector r);
}
