package jam.operator;

import  jam.vector.Vector;

/**
 * A <TT>hasGradient</TT> is an operator in which the gradient is
 * implemented.<BR>
 * We define the gradient as the adjoint of the derivative.<BR>
 * Thus, for a linear operator L, getGradientAt(Vector x), returns adj(L)<BR>
 * <BR>
 * In the case that the operator is a functional, i.e. the range is the set
 * of real numbers, people are used to thinking of the gradient as a vector.
 * A vector, v, can be thought of as an operator from real numbers to
 * the vector space of v.  The operator acts by simply multiplying the
 * scalar by the vector.  The adjoint of this is the operator which takes a
 * vector and returns the dot product of that vector and v.  This is the form
 * which is, technically speaking, the derivative of the functional.<BR>
 * This is in keeping with the fact that the derivative of an operator has
 * the same domain and range as the operator itself.  Therefore, the
 * derivative of a functional is actually a linear functional (i.e. a row
 * vector) instead of a vector (i.e. a column vector) as is usually taught
 * in Calculus classes.
 *
 * <BR><!--#include file="./source.inc"--><BR>
 * 
 * @author      Joel Schroeder
 */
public interface hasGradient extends jam.JamObject, Operator {
  /**
   * @param x the location at which the gradient is taken (irrelevant for linear operators)
   * @return  the operator's gradient at x
   */
  public LinearOperator getGradientAt(Vector x);
}
