package jam.operator;

import  jam.JamObject;
import  jam.vector.*;

/**
 * An <TT>hasHessian</TT> is an operator in which the Hessian, gradient,
 * and derivative are implemented.
 * The Hessian is a </TT>BiLinearOperatorAdjoint<TT>.
 * For a functional, we are used to thinking of the Hessian as a linear
 * operator.  In this case, we can retrieve the linear operator version from
 * the bilinear version by taking the "partial adjoint" of the bilinear
 * operator with the value new RealVec(1F).
 * <BR>
 *
 * <BR><!--#include file="./source.inc"--><BR>
 * 
 * @author      Joel Schroeder
 */
public interface hasHessian extends JamObject, hasDerivative {
  /**
   * @param x the location at which the Hessian is taken (irrelevant for linear and "quadratic" operators)
   * @return  the operator's Hessian at x
   */
  public BiLinearOperatorAdjoint getHessianAt(Vector x);
}
