package jam.solver;

/**
 * An <TT>Iterator</TT> controls the iterations of a solver.
 *
 * <BR><!--#include file="./source.inc"--><BR>
 * 
 * @author      Matt Schwab
 * @version     15 Mar 1997
 */
public interface Iterator { 
  /** 
   * A solver hands itself to the iterator to allow access to 
   * its methods
   */
  public void    setSolver(IterativeSolver solver);
  /**
   * A solver executes it before looping
   */
  public void    start();
  /**
   * A solver executes it every loop step to decide to continue looping 
   * @return false if solver is finished looping 
   */
  public boolean hasMoreIterations();
  /**
   * A solver executes it every loop step (after it updates the approximation,
   * but before it increments the iteration number)
   */
  public void    nextIteration();
  /**
   * A solver executes it after looping
   */
  public void    finish();
}
