package jam.vector;

import  jam.JamObject;

/**
 * A <TT>Vector</TT> is a mathematical vector with an inner product.<BR>
 * <BR><!--#include file="./source.inc"-->
 * 
 * <BR>
 * <B>Warning</B>: there is a potential conflict with
 * <TT>java.util.Vector</TT>.<BR>
 * One should avoid using <TT>import java.util.*;</TT><BR>
 * Import object from <TT>java.util</TT> on an individual basis, and never
 * import <TT>java.util.Vector</TT>.<BR>
 * Instead use <TT>java.util.Vector</TT> in full where needed.
 *
 * @author      Joel Schroeder
 */
public interface Vector extends JamObject {
  /**
   * @return The space of which <TT>this</TT> is a member.
   */
  public Space        getSpace();

  /**
   *  this = -this
   */
  public void         neg  ();
  /**
   *  this = -vec2
   */
  public void         neg  (Vector vec2);
  /**
   *  this = this  + vec2
   */
  public void         add  (Vector vec2);
  /**
   *  this = vec1 + vec2
   */
  public void         add  (Vector vec1,
			    Vector vec2);

  /**
   *  this = this + a*vec2
   */
  public void         addScale(float a,
			       Vector vec2);
  /**
   *  this = vec1 + a*vec2
   */
  public void         addScale(float a,
			       Vector vec1,
			       Vector vec2);

  /**
   *  this = this  - vec2
   */
  public void         sub  (Vector vec2);
  /**
   *  this = vec1 - vec2
   */
  public void         sub  (Vector vec1,
			    Vector vec2);

  /**
   *  this = a*this
   */
  public void         scale(float        a    );
  /**
   *  this = a*vec
   */
  public void         scale(float        a    ,
			    Vector vec2 );

  /**
   * this = src (without reallocating this)
   */
  public void         copyFrom(Vector src);

  /**
   * this = 0 (the zero vector)
   */
  public void         zero ();

  /**
   *  @return < this, vec2 > (the inner product)
   */
  public float dot  (Vector vec2);
  /**
   *  @return < this, this > ( = norm^2(this) )
   */
  public float norm2();
  /**
   *  @return sqrt( < this, this > ) ( = norm(this) )
   */
  public float norm ();
}
